@@ -1,7 +1,7 @@
 /*
  *   Copyright (C) 2006
  *   Siraj Razick <siraj@kdemail.net>
- *   PhobosK <phobosk@mail.kbfx.org>
+ *   PhobosK <phobosk@mail.kbfx.net>
  *   see Also AUTHORS
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@
 class KbfxPushButton: public KPushButton
 {
 		Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 		KbfxPushButton ( TQWidget *parent = 0, const char *name = 0 );
